You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ar...@apache.org on 2013/05/07 07:39:17 UTC

svn commit: r1479765 [1/3] - in /openoffice/trunk/main: sc/source/ui/app/ sc/source/ui/view/ sd/source/core/ sd/source/ui/animations/ sd/source/ui/view/ sfx2/sdi/ svx/ svx/inc/ svx/inc/svx/ svx/sdi/ svx/source/gallery2/ svx/source/items/ sw/source/ui/s...

Author: arielch
Date: Tue May  7 05:39:15 2013
New Revision: 1479765

URL: http://svn.apache.org/r1479765
Log:
i122116 - Remove GalleryExplorer member functions

Added:
    openoffice/trunk/main/svx/inc/svx/galleryitem.hxx
    openoffice/trunk/main/svx/source/items/galleryitem.cxx
Removed:
    openoffice/trunk/main/sc/source/ui/view/galwrap.cxx
Modified:
    openoffice/trunk/main/sc/source/ui/app/typemap.cxx
    openoffice/trunk/main/sc/source/ui/view/makefile.mk
    openoffice/trunk/main/sc/source/ui/view/tabvwsh9.cxx
    openoffice/trunk/main/sd/source/core/typemap.cxx
    openoffice/trunk/main/sd/source/ui/animations/CustomAnimationDialog.cxx
    openoffice/trunk/main/sd/source/ui/animations/SlideTransitionPane.cxx
    openoffice/trunk/main/sd/source/ui/view/drviews9.cxx
    openoffice/trunk/main/sfx2/sdi/sfx.sdi
    openoffice/trunk/main/svx/Library_svxcore.mk
    openoffice/trunk/main/svx/Package_inc.mk
    openoffice/trunk/main/svx/inc/GalleryControl.hxx
    openoffice/trunk/main/svx/inc/galbrws2.hxx
    openoffice/trunk/main/svx/inc/svx/galbrws.hxx
    openoffice/trunk/main/svx/inc/svx/gallery.hxx
    openoffice/trunk/main/svx/sdi/svx.sdi
    openoffice/trunk/main/svx/sdi/svxitems.sdi
    openoffice/trunk/main/svx/source/gallery2/GalleryControl.cxx
    openoffice/trunk/main/svx/source/gallery2/galbrws.cxx
    openoffice/trunk/main/svx/source/gallery2/galbrws2.cxx
    openoffice/trunk/main/svx/source/gallery2/galexpl.cxx
    openoffice/trunk/main/sw/source/ui/shells/basesh.cxx
    openoffice/trunk/main/sw/source/ui/shells/slotadd.cxx

Modified: openoffice/trunk/main/sc/source/ui/app/typemap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/ui/app/typemap.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/ui/app/typemap.cxx (original)
+++ openoffice/trunk/main/sc/source/ui/app/typemap.cxx Tue May  7 05:39:15 2013
@@ -30,32 +30,8 @@
 #include "scitems.hxx"
 #include <editeng/memberids.hrc>
 
-
 #define	ITEMID_DBTYPE			0
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #include <sfx2/msg.hxx>
 #include <svl/stritem.hxx>
 #include <svl/slstitm.hxx>
@@ -135,6 +111,7 @@
 #include <svx/xlncapit.hxx>
 #include <svx/xlinjoit.hxx>
 #include <svx/AffineMatrixItem.hxx>
+#include <svx/galleryitem.hxx>
 
 #define SFX_TYPEMAP
 #include "scslots.hxx"

Modified: openoffice/trunk/main/sc/source/ui/view/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/ui/view/makefile.mk?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/ui/view/makefile.mk (original)
+++ openoffice/trunk/main/sc/source/ui/view/makefile.mk Tue May  7 05:39:15 2013
@@ -102,7 +102,6 @@ SLOFILES =  \
         $(SLO)$/hdrcont.obj \
         $(SLO)$/colrowba.obj \
         $(SLO)$/olkact.obj \
-        $(SLO)$/galwrap.obj \
         $(SLO)$/imapwrap.obj \
         $(SLO)$/reffact.obj \
         $(SLO)$/selectionstate.obj \

Modified: openoffice/trunk/main/sc/source/ui/view/tabvwsh9.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/ui/view/tabvwsh9.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/core/typemap.cxx (original)
+++ openoffice/trunk/main/sd/source/core/typemap.cxx Tue May  7 05:39:15 2013
@@ -132,6 +132,7 @@
 #include <svx/xflftrit.hxx>
 #include <svx/xlinjoit.hxx>
 #include <svx/AffineMatrixItem.hxx>
+#include <svx/galleryitem.hxx>
 
 #define SFX_TYPEMAP
 #include "sdslots.hxx"

Modified: openoffice/trunk/main/sd/source/ui/animations/CustomAnimationDialog.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/animations/CustomAnimationDialog.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/animations/CustomAnimationDialog.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/animations/CustomAnimationDialog.cxx Tue May  7 05:39:15 2013
@@ -1803,7 +1803,7 @@ void CustomAnimationEffectTabPage::openS
 		if( nPos < 0 ) // not in Soundliste
 		{
 			// try to insert in Gallery
-			if( GalleryExplorer::InsertURL( GALLERY_THEME_USERSOUNDS, aFile, SGA_FORMAT_SOUND ) )
+			if( GalleryExplorer::InsertURL( GALLERY_THEME_USERSOUNDS, aFile ) )
 			{
 				clearSoundListBox();
 				fillSoundListBox();

Modified: openoffice/trunk/main/sd/source/ui/animations/SlideTransitionPane.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/animations/SlideTransitionPane.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/animations/SlideTransitionPane.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/animations/SlideTransitionPane.cxx Tue May  7 05:39:15 2013
@@ -976,7 +976,7 @@ void SlideTransitionPane::openSoundFileD
 		else // not in sound list
 		{
 			// try to insert into gallery
-			if( GalleryExplorer::InsertURL( GALLERY_THEME_USERSOUNDS, aFile, SGA_FORMAT_SOUND ) )
+			if( GalleryExplorer::InsertURL( GALLERY_THEME_USERSOUNDS, aFile ) )
 			{
                 updateSoundList();
                 bValidSoundFile = lcl_findSoundInList( maSoundList, aFile, nPos );

Modified: openoffice/trunk/main/sd/source/ui/view/drviews9.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/drviews9.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/drviews9.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/drviews9.cxx Tue May  7 05:39:15 2013
@@ -68,6 +68,9 @@
 #include "sdresid.hxx"
 #include "fupoor.hxx"
 
+#include <svx/galleryitem.hxx>
+#include <com/sun/star/gallery/GalleryItemType.hpp>
+
 namespace sd {
 
 #ifndef SO2_DECL_SVINPLACEOBJECT_DEFINED
@@ -94,131 +97,127 @@ void DrawViewShell::ExecGallery(SfxReque
 
 	const SfxItemSet* pArgs = rReq.GetArgs();
 
-	if ( pArgs )
-	{
-		const sal_uInt32		nFormats = ( (SfxUInt32Item&) pArgs->Get( SID_GALLERY_FORMATS ) ).GetValue();
-		GalleryExplorer*	pGal = SVX_GALLERY();
-
-		if ( pGal )
-		{
-			GetDocSh()->SetWaitCursor( sal_True );
-
-			// Graphik einfuegen
-			if (nFormats & SGA_FORMAT_GRAPHIC)
-			{
-				Graphic aGraphic = pGal->GetGraphic();
-
-				// Ggf. Groesse reduzieren
-				Window aWindow (GetActiveWindow());
-				aWindow.SetMapMode(aGraphic.GetPrefMapMode());
-				Size aSizePix = aWindow.LogicToPixel(aGraphic.GetPrefSize());
-				aWindow.SetMapMode( MapMode(MAP_100TH_MM) );
-				Size aSize = aWindow.PixelToLogic(aSizePix);
-
-				// Groesse ggf. auf Seitengroesse begrenzen
-				SdrPage* pPage = mpDrawView->GetSdrPageView()->GetPage();
-				Size aPageSize = pPage->GetSize();
-				aPageSize.Width() -= pPage->GetLftBorder() + pPage->GetRgtBorder();
-				aPageSize.Height() -= pPage->GetUppBorder() + pPage->GetLwrBorder();
-
-
-				// Falls Grafik zu gross, wird die Grafik
-				// in die Seite eingepasst
-				if ( ( ( aSize.Height() > aPageSize.Height() ) || ( aSize.Width()	> aPageSize.Width() ) ) &&
-					aSize.Height() && aPageSize.Height() )
-				{
-					float fGrfWH =	(float)aSize.Width() /
-									(float)aSize.Height();
-					float fWinWH =	(float)aPageSize.Width() /
-									(float)aPageSize.Height();
-
-					// Grafik an Pagesize anpassen (skaliert)
-					if ((fGrfWH != 0.F) && (fGrfWH < fWinWH))
-					{
-						aSize.Width() = (long)(aPageSize.Height() * fGrfWH);
-						aSize.Height()= aPageSize.Height();
-					}
-					else
-					{
-						aSize.Width() = aPageSize.Width();
-						aSize.Height()= (long)(aPageSize.Width() / fGrfWH);
-					}
-				}
+    SFX_ITEMSET_ARG( pArgs, pGalleryItem, SvxGalleryItem, SID_GALLERY_FORMATS, sal_False );
+    if ( !pGalleryItem )
+        return;
+
+    GetDocSh()->SetWaitCursor( sal_True );
+
+    sal_Int8 nType( pGalleryItem->GetType() );
+    // Graphik einfuegen
+    if (nType == com::sun::star::gallery::GalleryItemType::GRAPHIC)
+    {
+        Graphic aGraphic( pGalleryItem->GetGraphic() );
+
+        // Ggf. Groesse reduzieren
+        Window aWindow (GetActiveWindow());
+        aWindow.SetMapMode(aGraphic.GetPrefMapMode());
+        Size aSizePix = aWindow.LogicToPixel(aGraphic.GetPrefSize());
+        aWindow.SetMapMode( MapMode(MAP_100TH_MM) );
+        Size aSize = aWindow.PixelToLogic(aSizePix);
+
+        // Groesse ggf. auf Seitengroesse begrenzen
+        SdrPage* pPage = mpDrawView->GetSdrPageView()->GetPage();
+        Size aPageSize = pPage->GetSize();
+        aPageSize.Width() -= pPage->GetLftBorder() + pPage->GetRgtBorder();
+        aPageSize.Height() -= pPage->GetUppBorder() + pPage->GetLwrBorder();
+
+
+        // Falls Grafik zu gross, wird die Grafik
+        // in die Seite eingepasst
+        if ( ( ( aSize.Height() > aPageSize.Height() ) || ( aSize.Width()	> aPageSize.Width() ) ) &&
+            aSize.Height() && aPageSize.Height() )
+        {
+            float fGrfWH =	(float)aSize.Width() /
+                            (float)aSize.Height();
+            float fWinWH =	(float)aPageSize.Width() /
+                            (float)aPageSize.Height();
+
+            // Grafik an Pagesize anpassen (skaliert)
+            if ((fGrfWH != 0.F) && (fGrfWH < fWinWH))
+            {
+                aSize.Width() = (long)(aPageSize.Height() * fGrfWH);
+                aSize.Height()= aPageSize.Height();
+            }
+            else
+            {
+                aSize.Width() = aPageSize.Width();
+                aSize.Height()= (long)(aPageSize.Width() / fGrfWH);
+            }
+        }
+
+
+        // Ausgaberechteck fuer Grafik setzen
+        Point aPnt ((aPageSize.Width()	- aSize.Width())  / 2,
+                    (aPageSize.Height() - aSize.Height()) / 2);
+        aPnt += Point(pPage->GetLftBorder(), pPage->GetUppBorder());
+        Rectangle aRect (aPnt, aSize);
+
+        SdrGrafObj* pGrafObj = NULL;
+
+        sal_Bool bInsertNewObject = sal_True;
+
+        if ( mpDrawView->AreObjectsMarked() )
+        {
+            /******************************************************
+            * Ist ein leeres Graphik-Objekt vorhanden?
+            ******************************************************/
+            const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
+
+            if (rMarkList.GetMarkCount() == 1)
+            {
+                SdrMark* pMark = rMarkList.GetMark(0);
+                SdrObject* pObj = pMark->GetMarkedSdrObj();
+
+                if (pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_GRAF)
+                {
+                    pGrafObj = (SdrGrafObj*) pObj;
+
+                    if( pGrafObj->IsEmptyPresObj() )
+                    {
+                        /******************************************
+                        * Das leere Graphik-Objekt bekommt eine neue
+                        * Graphik
+                        ******************************************/
+                        bInsertNewObject = sal_False;
+
+                        SdrGrafObj* pNewGrafObj = (SdrGrafObj*) pGrafObj->Clone();
+                        pNewGrafObj->SetEmptyPresObj(sal_False);
+                        pNewGrafObj->SetOutlinerParaObject(NULL);
+                        pNewGrafObj->SetGraphic(aGraphic);
+
+                        String aStr(mpDrawView->GetDescriptionOfMarkedObjects());
+                        aStr += sal_Unicode(' ');
+                        aStr += String(SdResId(STR_UNDO_REPLACE));
+                        mpDrawView->BegUndo(aStr);
+                        SdrPageView* pPV = mpDrawView->GetSdrPageView();
+                        mpDrawView->ReplaceObjectAtView(pGrafObj, *pPV, pNewGrafObj);
+                        mpDrawView->EndUndo();
+                    }
+                }
+            }
+        }
+
+
+        if( bInsertNewObject )
+        {
+            pGrafObj = new SdrGrafObj(aGraphic, aRect);
+            SdrPageView* pPV = mpDrawView->GetSdrPageView();
+            mpDrawView->InsertObjectAtView(pGrafObj, *pPV, SDRINSERT_SETDEFLAYER);
+        }
+
+        // Soll nur ein Link benutzt werden?
+        if( pGrafObj && pGalleryItem->IsLink() )
+            pGrafObj->SetGraphicLink( pGalleryItem->GetURL(), pGalleryItem->GetFilterName() );
+    }
+    // insert sound
+    else if( nType == com::sun::star::gallery::GalleryItemType::MEDIA )
+    {
+        const SfxStringItem aMediaURLItem( SID_INSERT_AVMEDIA, pGalleryItem->GetURL() );
+        GetViewFrame()->GetDispatcher()->Execute( SID_INSERT_AVMEDIA, SFX_CALLMODE_SYNCHRON, &aMediaURLItem, 0L );
+    }
 
-
-				// Ausgaberechteck fuer Grafik setzen
-				Point aPnt ((aPageSize.Width()	- aSize.Width())  / 2,
-							(aPageSize.Height() - aSize.Height()) / 2);
-				aPnt += Point(pPage->GetLftBorder(), pPage->GetUppBorder());
-				Rectangle aRect (aPnt, aSize);
-
-				SdrGrafObj* pGrafObj = NULL;
-
-				sal_Bool bInsertNewObject = sal_True;
-
-				if ( mpDrawView->AreObjectsMarked() )
-				{
-					/******************************************************
-					* Ist ein leeres Graphik-Objekt vorhanden?
-					******************************************************/
-					const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
-
-					if (rMarkList.GetMarkCount() == 1)
-					{
-						SdrMark* pMark = rMarkList.GetMark(0);
-						SdrObject* pObj = pMark->GetMarkedSdrObj();
-
-						if (pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_GRAF)
-						{
-							pGrafObj = (SdrGrafObj*) pObj;
-
-							if( pGrafObj->IsEmptyPresObj() )
-							{
-								/******************************************
-								* Das leere Graphik-Objekt bekommt eine neue
-								* Graphik
-								******************************************/
-								bInsertNewObject = sal_False;
-
-								SdrGrafObj* pNewGrafObj = (SdrGrafObj*) pGrafObj->Clone();
-								pNewGrafObj->SetEmptyPresObj(sal_False);
-								pNewGrafObj->SetOutlinerParaObject(NULL);
-								pNewGrafObj->SetGraphic(aGraphic);
-
-								String aStr(mpDrawView->GetDescriptionOfMarkedObjects());
-								aStr += sal_Unicode(' ');
-								aStr += String(SdResId(STR_UNDO_REPLACE));
-								mpDrawView->BegUndo(aStr);
-								SdrPageView* pPV = mpDrawView->GetSdrPageView();
-								mpDrawView->ReplaceObjectAtView(pGrafObj, *pPV, pNewGrafObj);
-								mpDrawView->EndUndo();
-							}
-						}
-					}
-				}
-
-
-				if( bInsertNewObject )
-				{
-					pGrafObj = new SdrGrafObj(aGraphic, aRect);
-					SdrPageView* pPV = mpDrawView->GetSdrPageView();
-					mpDrawView->InsertObjectAtView(pGrafObj, *pPV, SDRINSERT_SETDEFLAYER);
-				}
-
-				// Soll nur ein Link benutzt werden?
-				if( pGrafObj && pGal->IsLinkage() )
-					pGrafObj->SetGraphicLink( pGal->GetURL().GetMainURL( INetURLObject::NO_DECODE ), pGal->GetFilterName() );
-			}
-			// insert sound
-			else if( nFormats & SGA_FORMAT_SOUND )
-			{
-        		const SfxStringItem aMediaURLItem( SID_INSERT_AVMEDIA, pGal->GetURL().GetMainURL( INetURLObject::NO_DECODE ) );
-       			GetViewFrame()->GetDispatcher()->Execute( SID_INSERT_AVMEDIA, SFX_CALLMODE_SYNCHRON, &aMediaURLItem, 0L );
-			}
-
-			GetDocSh()->SetWaitCursor( sal_False );
-		}
-	}
+    GetDocSh()->SetWaitCursor( sal_False );
 }
 
 

Modified: openoffice/trunk/main/sfx2/sdi/sfx.sdi
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/sdi/sfx.sdi?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/sdi/sfx.sdi (original)
+++ openoffice/trunk/main/sfx2/sdi/sfx.sdi Tue May  7 05:39:15 2013
@@ -474,34 +474,6 @@ SfxVoidItem AutoPilotMenu SID_AUTOPILOTM
 ]
 
 //--------------------------------------------------------------------------
-SfxVoidItem BackgroundImage SID_GALLERY_BG_BRUSH
-(SfxStringItem ImageFile SID_FILE_NAME)
-[
-	/* flags: */
-	AutoUpdate = FALSE,
-	Cachable = Cachable,
-	FastCall = TRUE,
-	HasCoreId = FALSE,
-	HasDialog = FALSE,
-	ReadOnlyDoc = FALSE,
-	Toggle = FALSE,
-	Container = FALSE,
-	RecordAbsolute = FALSE,
-	RecordPerSet;
-	Synchron;
-
-	/* status: */
-	SlotType = SfxStringItem
-
-	/* config: */
-	AccelConfig = FALSE,
-	MenuConfig = FALSE,
-	StatusBarConfig = FALSE,
-	ToolBoxConfig = FALSE,
-	GroupId = GID_INSERT;
-]
-
-//--------------------------------------------------------------------------
 SfxVoidItem Backspace SID_BACKSPACE
 ()
 [

Modified: openoffice/trunk/main/svx/Library_svxcore.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/svx/Library_svxcore.mk?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================
--- openoffice/trunk/main/svx/Library_svxcore.mk (original)
+++ openoffice/trunk/main/svx/Library_svxcore.mk Tue May  7 05:39:15 2013
@@ -184,6 +184,7 @@ $(eval $(call gb_Library_add_exception_o
     svx/source/items/customshapeitem \
     svx/source/items/drawitem \
     svx/source/items/e3ditem \
+    svx/source/items/galleryitem \
     svx/source/items/grfitem \
     svx/source/sdr/animation/scheduler \
     svx/source/sdr/animation/objectanimator \
--- openoffice/trunk/main/sc/source/ui/view/tabvwsh9.cxx (original)
+++ openoffice/trunk/main/sc/source/ui/view/tabvwsh9.cxx Tue May  7 05:39:15 2013
@@ -47,13 +47,8 @@
 #include "userdat.hxx"
 #include "docsh.hxx"
 
-// forwards -> galwrap.cxx (wg. CLOOKs)
-
-sal_uInt16	GallerySGA_FORMAT_GRAPHIC();
-Graphic GalleryGetGraphic		();
-sal_Bool	GalleryIsLinkage		();
-String	GalleryGetFullPath		();
-String	GalleryGetFilterName	();
+#include <svx/galleryitem.hxx>
+#include <com/sun/star/gallery/GalleryItemType.hpp>
 
 // forwards -> imapwrap.cxx (wg. CLOOKs)
 
@@ -109,49 +104,36 @@ void ScTabViewShell::GetChildWinState( S
 
 void ScTabViewShell::ExecGallery( SfxRequest& rReq )
 {
-	const SfxItemSet* pArgs = rReq.GetArgs();
-
-	if ( pArgs )
-	{
-		const SfxPoolItem* pItem = NULL;
-		SfxItemState eState = pArgs->GetItemState(SID_GALLERY_FORMATS, sal_True, &pItem);
-		if ( eState == SFX_ITEM_SET )
-		{
-			sal_uInt32 nFormats = ((const SfxUInt32Item*)pItem)->GetValue();
-
-			/******************************************************************
-			* Graphik einfuegen
-			******************************************************************/
-			if ( nFormats & GallerySGA_FORMAT_GRAPHIC() )
-			{
-				MakeDrawLayer();
-
-				Graphic aGraphic = GalleryGetGraphic();
-				Point 	aPos     = GetInsertPos();
-
-				String aPath, aFilter;
-				if ( GalleryIsLinkage() )			// als Link einfuegen?
-				{
-					aPath = GalleryGetFullPath();
-					aFilter = GalleryGetFilterName();
-				}
+    const SfxItemSet* pArgs = rReq.GetArgs();
 
-				PasteGraphic( aPos, aGraphic, aPath, aFilter );
-			}
-			else if ( nFormats & SGA_FORMAT_SOUND )
-			{
-				//	#98115# for sounds (linked or not), insert a hyperlink button,
-				//	like in Impress and Writer
-
-				GalleryExplorer* pGal = SVX_GALLERY();
-				if ( pGal )
-				{
-        		    const SfxStringItem aMediaURLItem( SID_INSERT_AVMEDIA, pGal->GetURL().GetMainURL( INetURLObject::NO_DECODE ) );
-       			    GetViewFrame()->GetDispatcher()->Execute( SID_INSERT_AVMEDIA, SFX_CALLMODE_SYNCHRON, &aMediaURLItem, 0L );
-				}
-			}
-		}
-	}
+    SFX_ITEMSET_ARG( pArgs, pGalleryItem, SvxGalleryItem, SID_GALLERY_FORMATS, sal_False );
+    if ( !pGalleryItem )
+        return;
+
+    sal_Int8 nType( pGalleryItem->GetType() );
+    if ( nType == com::sun::star::gallery::GalleryItemType::GRAPHIC )
+    {
+        MakeDrawLayer();
+
+        Graphic aGraphic( pGalleryItem->GetGraphic() );
+        Point 	aPos     = GetInsertPos();
+
+        String aPath, aFilter;
+        if ( pGalleryItem->IsLink() ) // als Link einfuegen?
+        {
+            aPath = pGalleryItem->GetURL();
+            aFilter = pGalleryItem->GetFilterName();
+        }
+
+        PasteGraphic( aPos, aGraphic, aPath, aFilter );
+    }
+    else if ( nType == com::sun::star::gallery::GalleryItemType::MEDIA )
+    {
+        //	#98115# for sounds (linked or not), insert a hyperlink button,
+        //	like in Impress and Writer
+        const SfxStringItem aMediaURLItem( SID_INSERT_AVMEDIA, pGalleryItem->GetURL() );
+        GetViewFrame()->GetDispatcher()->Execute( SID_INSERT_AVMEDIA, SFX_CALLMODE_SYNCHRON, &aMediaURLItem, 0L );
+    }
 }
 
 void ScTabViewShell::GetGalleryState( SfxItemSet& /* rSet */ )

Modified: openoffice/trunk/main/sd/source/core/typemap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/core/typemap.cxx?rev=1479765&r1=1479764&r2=1479765&view=diff
==============================================================================